%process_database

% FINGERPRINT DIMENSION REDUCTION STUDY

% reload fingerprints b/c it was previously truncated to 7kHz
load 'fingerprints.txt';

good_fps = fingerprints(good_room_indices,:);

intra_var = zeros( 1, size( good_fps, 2 )  );
for i=1:length(good_rooms),
    % accumulate intra room variance
    intra_var = intra_var + var( good_fps( (4*(i-1)+1):4*i, : ), 0, 1 );   
end
total_var = var( good_fps, 0, 1 );

dim_goodness = total_var ./ intra_var;
dim_goodness = dim_goodness * length(good_rooms); % normalize by population
                                                  % size

f = 1:((44100/2)/1024):44100/2;
figure
plot( f, dim_goodness );
title( 'Usefulness of frequencies' );
ylabel( 'population variance / intra-room variance (normalized)' );
xlabel( 'frequency');
grid on;

% fit gaussian to our frequency figure-of-merit
figure
[sigma,mu,A] = mygaussfit( f, dim_goodness-1, 0.2 );              
weights = A * exp(-((f-mu).^2) / (2*sigma^2 ))
plot( f, dim_goodness-1, '.', f, weights, '-', 'LineWidth', 3 );
title( sprintf('fitting for the weighting factor: mu=%f sigma=%f A=%f', mu, ...
               sigma, A ) );
ylabel( 'weighting factor' );
xlabel( 'frequency');
grid on;
