function z = scatter_hist( X, Y, n, normalize )
% return a 2d histogram of the paired data represented by the column vectors
% X and Y.  n is the number of bins in the histogram.  Also, plots the
% histogram as an image.
% normalize can, optionally be set to 'row' or 'column' to normalize the data
% along that dimension.

xi=linspace(min(X), max(X), n );
yi=linspace(min(Y), max(Y), n );
xr= interp1(xi,1:numel(xi), X, 'nearest' );
yr= interp1(yi,1:numel(yi), Y, 'nearest' );
% [yr xr]: Y then X because the plotting commands take matrices that look
% like Z(y-coord, x-coord)
z = accumarray([yr xr],1,[n n]);

% normalize, if desired
if( nargin > 3 )
    if( strcmp( normalize, 'row' ) )
        z = z ./ repmat( hist(yr,n)', 1, n );
    elseif( strcmp( normalize, 'column' ) )
        z = z ./ repmat( hist(xr,n), n, 1 );
    end
end

figure
colormap(1-gray(256));
imagesc( [min(X) max(X)], [min(Y) max(Y)], z);
set(gca,'YDir','normal');

